@@ -1,33 +1,33 @@
 const javascriptSettings = {
-  files: ['*.js'],
+  files: ['*.js', '*.mjs'],
   extends: [
     'standard',
     'plugin:jest/recommended'
   ],
   rules: {
     'no-else-return': ['error', { allowElseIf: false }],
-    'no-var': 'warn',
-    'one-var': 'off',
     'space-before-function-paren': ['error', 'never'],
-    semi: ['error', 'always']
+    // manual "semistandard" settings
+    semi: ['error', 'always'],
+    'no-extra-semi': 'error'
   }
 };
 
 const typescriptSettings = {
   files: ['*.ts'],
-  extends: ['standard-with-typescript'],
   parserOptions: {
     project: './tsconfig.json'
   },
+  plugins: [
+    '@typescript-eslint'
+  ],
+  extends: [
+    'standard-with-typescript'
+  ],
   rules: {
     'no-else-return': ['error', { allowElseIf: false }],
-    'no-var': 'warn',
-    'one-var': 'off',
-    'space-before-function-paren': ['error', 'never'],
-    // Using method rather than property for method-signature-style, to document method overloads separately.
-    '@typescript-eslint/method-signature-style': ['warn', 'method'],
-    semi: 'off',
-    '@typescript-eslint/semi': ['error', 'always'],
+    'space-before-function-paren': 'off',
+    '@typescript-eslint/space-before-function-paren': ['error', 'never'],
     '@typescript-eslint/member-delimiter-style': [
       'error',
       {
@@ -40,7 +40,12 @@ const typescriptSettings = {
           requireLast: false
         }
       }
-    ]
+    ],
+    // manual "semistandard" settings
+    semi: 'off',
+    '@typescript-eslint/semi': ['error', 'always'],
+    'no-extra-semi': 'off',
+    '@typescript-eslint/no-extra-semi': ['error']
   }
 };
 
@@ -51,6 +56,12 @@ module.exports = {
   },
   overrides: [
     javascriptSettings,
-    typescriptSettings
+    typescriptSettings,
+    {
+      files: ['*.mjs'],
+      parserOptions: {
+        sourceType: 'module'
+      }
+    }
   ]
 };
