@@ -2,20 +2,7 @@
 
 // This is used as an example in the README for:
 //    Custom option processing
-//    You may specify a function to do custom processing of option values. ...
-//
-// Example output pretending command called custom (or try directly with `node options-custom-processing.js`)
-//
-// $ custom -f 1e2
-// float: 100
-// $ custom --integer 2
-// integer: 2
-// $ custom -v -v -v
-// verbose: 3
-// $ custom -c a -c b -c c
-// [ 'a', 'b', 'c' ]
-// $ custom --list x,y,z
-// [ 'x', 'y', 'z' ]
+//    You may specify a function to do custom processing of option values.
 
 // const commander = require('commander'); // (normal include)
 const commander = require('../'); // include commander in git clone of commander repo
@@ -23,7 +10,11 @@ const program = new commander.Command();
 
 function myParseInt(value, dummyPrevious) {
   // parseInt takes a string and a radix
-  return parseInt(value, 10);
+  const parsedValue = parseInt(value, 10);
+  if (isNaN(parsedValue)) {
+    throw new commander.InvalidArgumentError('Not a number.');
+  }
+  return parsedValue;
 }
 
 function increaseVerbosity(dummyValue, previous) {
@@ -46,9 +37,18 @@ program
   .option('-l, --list <items>', 'comma separated list', commaSeparatedList)
 ;
 
-program.parse(process.argv);
-if (program.float !== undefined) console.log(`float: ${program.float}`);
-if (program.integer !== undefined) console.log(`integer: ${program.integer}`);
-if (program.verbose > 0) console.log(`verbosity: ${program.verbose}`);
-if (program.collect.length > 0) console.log(program.collect);
-if (program.list !== undefined) console.log(program.list);
+program.parse();
+
+const options = program.opts();
+if (options.float !== undefined) console.log(`float: ${options.float}`);
+if (options.integer !== undefined) console.log(`integer: ${options.integer}`);
+if (options.verbose > 0) console.log(`verbosity: ${options.verbose}`);
+if (options.collect.length > 0) console.log(options.collect);
+if (options.list !== undefined) console.log(options.list);
+
+// Try the following:
+//    node options-custom-processing -f 1e2
+//    node options-custom-processing --integer 2
+//    node options-custom-processing -v -v -v
+//    node options-custom-processing -c a -c b -c c
+//    node options-custom-processing --list x,y,z
