@@ -3,17 +3,6 @@
 // This is used as an example in the README for:
 //    Other option types, negatable boolean
 //    You can specify a boolean option long name with a leading `no-` to make it true by default and able to be negated.
-//
-// Example output pretending command called pizza-options (or try directly with `node options-negatable.js`)
-//
-// $ pizza-options
-// You ordered a pizza with sauce and mozzarella cheese
-// $ pizza-options --sauce
-// error: unknown option '--sauce'
-// $ pizza-options --cheese=blue
-// You ordered a pizza with sauce and blue cheese
-// $ pizza-options --no-sauce --no-cheese
-// You ordered a pizza with no sauce and no cheese
 
 // const commander = require('commander'); // (normal include)
 const commander = require('../'); // include commander in git clone of commander repo
@@ -24,8 +13,15 @@ program
   .option('--cheese <flavour>', 'cheese flavour', 'mozzarella')
   .option('--no-cheese', 'plain with no cheese');
 
-program.parse(process.argv);
+program.parse();
 
-const sauceStr = program.sauce ? 'sauce' : 'no sauce';
-const cheeseStr = (program.cheese === false) ? 'no cheese' : `${program.cheese} cheese`;
+const options = program.opts();
+const sauceStr = options.sauce ? 'sauce' : 'no sauce';
+const cheeseStr = (options.cheese === false) ? 'no cheese' : `${options.cheese} cheese`;
 console.log(`You ordered a pizza with ${sauceStr} and ${cheeseStr}`);
+
+// Try the following:
+//    node options-negatable.js
+//    node options-negatable.js --sauce
+//    node options-negatable.js --cheese=blue
+//    node options-negatable.js --no-sauce --no-cheese
