@@ -8,6 +8,6 @@ test('when when multiple short flags specified then all values are true', () =>
 
   program.parse(['node', 'test', '-pc']);
 
-  expect(program.pepper).toBe(true);
-  expect(program.cheese).toBe(true);
+  expect(program.opts().pepper).toBe(true);
+  expect(program.opts().cheese).toBe(true);
 });
